<?php

namespace TDevAgency\Erp\Controllers;

use TDevAgency\Erp\Models\Container;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Http\RedirectResponse;
use Illuminate\Http\Request;
use Illuminate\Http\Response;
use Illuminate\Support\Facades\Redirect;
use Illuminate\Support\Facades\View;
use Illuminate\Validation\Rule;
use Illuminate\Validation\ValidationException;
use TDevAgency\Cms\Controllers\Controller;
use TDevAgency\Cms\Models\BaseModels\AdminUser;

class ContainerController extends Controller
{

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Contracts\View\View
     */
    public function index()
    {
        return View::make('erp::pages.containers.index', ['containers' => Container::paginate(30)]);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Contracts\View\View
     */
    public function create()
    {
        $view = View::make('erp::pages.containers.single');
        $container = new Container();
        $view->with('container', $container)
            ->with('users', $this->users())
            ->with('formRoute', route('cms.containers.store'))
            ->with('formMethod', 'POST');
        return $view;
    }

    private function users()
    {
        return AdminUser::whereHas('roles', function (Builder $query) {
            return $query->where('admin_role', 'owner');
        })->pluck('name', 'id');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param Request $request
     * @return RedirectResponse
     * @throws ValidationException
     */
    public function store(Request $request)
    {
        $this->validate($this->request, [
            'admin_user_id' => ['required', Rule::unique('containers')],
            'container_name' => 'required|string',
        ], $this->validationCustomAttributes());

        $container = new Container();
        $this->setDataToModel($container);
        $container->save();

        return Redirect::route('cms.containers.index')->with('toast', [
            'title' => trans('cms::admin.toast.created'),
            'status' => 'success'
        ]);
    }

    private function validationCustomAttributes()
    {
        return [
            'admin_user_id' => trans('erp::erp.owner'),
            'container_name' => trans('erp::erp.container_name')
        ];
    }

    /**
     * Display the specified resource.
     *
     * @param Container $container
     * @return Response
     */
    public function show(Container $container)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param Container $container
     * @return \Illuminate\Contracts\View\View
     */
    public function edit(Container $container)
    {
        $view = View::make('erp::pages.containers.single');
        $view->with('container', $container)
            ->with('users', $this->users());
        $view->with('formRoute', route('cms.containers.update', $container->id));
        $view->with('formMethod', 'PUT');
        return $view;
    }

    /**
     * Update the specified resource in storage.
     *
     * @param Request $request
     * @param Container $container
     * @return RedirectResponse
     * @throws ValidationException
     */
    public function update(Request $request, Container $container)
    {
        $this->validate($this->request, [
            'admin_user_id' => ['required',
                Rule::unique(Container::class)->ignore($container->admin_user_id, 'admin_user_id')
            ],
            'container_name' => 'required|string',
        ], $this->validationCustomAttributes());
        $this->setDataToModel($container);
        $container->update();

        return Redirect::route('cms.containers.index')->with('toast', [
            'title' => trans('cms::admin.toast.updated'),
            'status' => 'success'
        ]);
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param Container $container
     * @return Response
     */
    public function destroy(Container $container)
    {
        //TODO deletetion whole container
    }
}
