<?php

namespace TDevAgency\Erp\Models;

use Illuminate\Contracts\Encryption\DecryptException;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Crypt;
use TDevAgency\Erp\Traits\Containerable;

class CoreConfig extends Model
{
    use Containerable;

    protected $fillable = ['container_id', 'config_key', 'config_value', 'is_encrypted'];

    protected static function boot()
    {
        parent::boot();
        parent::saving(function (Model $model) {
            try {
                Crypt::decrypt($model->config_value);
                $decrypted = true;
            } catch (DecryptException $e) {
                $decrypted = false;
            }
            if ($model->getAttribute('is_encrypted') && !$decrypted) {
                $model->setAttribute('config_value', Crypt::encrypt($model->config_value));
            }
        });

    }

    /**
     * @return array
     */
    public function toArray(): array
    {
        return [
            'config_key' => $this->config_key,
            'config_value' => $this->is_encrypted ? Crypt::decrypt($this->config_value) : $this->config_value,
            'is_encrypted' => $this->is_encrypted !== false,
        ];
    }
}
