<?php


namespace TDevAgency\Erp\Helpers;


use claviska\SimpleImage;
use Illuminate\Http\UploadedFile;
use Illuminate\Support\Facades\File;
use Illuminate\Support\Facades\Storage;
use Illuminate\Support\Str;
use TdevAgency\Erp\Interfaces\ErpModel;
use TDevAgency\FilesManager\ResourceModels\TdfmFile;

class Image
{

    /**
     * @var SimpleImage
     */
    private $simpleImage;

    /**
     * Image constructor.
     */
    public function __construct()
    {
        $this->simpleImage = new SimpleImage();
    }

    /**
     * @param UploadedFile $file
     * @param ErpModel $model
     * @return string
     */
    public function generateImages(UploadedFile $file, ErpModel $model): string
    {


        $fileName = Str::slug($model->getName()) . '.' . $file->getClientOriginalExtension();
        $path = sprintf('%s/%s', $model->getTable(), $model->getId());

        Storage::disk('public')->putFileAs($path, $file, $fileName);

        if (preg_match('/^image\/(jpe?g|gif|png)+$/', $file->getClientMimeType())) {
            /** @var SimpleImage $imgage */
            $this->generateSizes($file, $model, $fileName);
        }

        return $fileName;
    }

    private function generateSizes(UploadedFile $file, ErpModel $model, $fileName): void
    {
        $name = Str::slug($model->getName());
        if (is_array($model->getImageSizes()) && !empty($model->getImageSizes())) {
            foreach ($model->getImageSizes() as $key => $size) {
                /**
                 * @var UploadedFile $newFile
                 */
                $newFile = clone $file;
                $image = $this->simpleImage->fromString($newFile->get());

                $width = $image->getWidth() < $size ? $image->getWidth() : $size;
                if ($key !== 'xs') {
                    $image->resize($width);
                } else {
                    $image->thumbnail($width, $width, 'center');
                }
                $image->autoOrient();

                $path = sprintf('%s/%s/%s/', $model->getTable(), $model->getId(), $key);

                if (!Storage::disk('public')->exists($path)) {
                    Storage::disk('public')->makeDirectory($path);
                }
                $path = Storage::disk('public')->path($path);
                $image->toFile($path . $fileName, $newFile->getClientMimeType(), 85);
                $image->toFile($path . $name . '.' . 'webp', 'image/webp', 85);
            }
        }
    }

    public function getImage(ErpModel $model, $array = true, $size = null)
    {


        $name = $model->getImageName();

        if (strpos($name, '.svg') !== false) {
            return Storage::disk('public')->url(sprintf('%s/%s/%s', $model->getTable(), $model->getId(), $model->getImageName()));
        }

        if (strpos(request()->headers->get('accept'), 'image/webp') !== false) {
            $name = pathinfo($name, PATHINFO_FILENAME) . '.webp';
        }
        if ($size === null) {
            $path = sprintf('%s/%s/%s', $model->getTable(), $model->getId(), $name);
        } else {
            $path = sprintf('%s/%s/%s/%s', $model->getTable(), $model->getId(), $size, $name);
        }

        return Storage::disk('public')->url($path);

    }

}
